pub struct Mode(/* private fields */);Expand description
The set of measurements an analyzer should compute.
Combine with |:
use ebur128_stream::Mode;
let modes = Mode::Integrated | Mode::TruePeak;
assert!(modes.contains(Mode::Integrated));Implementations
Sourceimpl Mode
impl Mode
Sourcepub const Integrated: Self
pub const Integrated: Self
Integrated loudness over the full programme, gated per
BS.1770-4 5.6. Reported via Report::integrated_lufs.
Sourcepub const Momentary: Self
pub const Momentary: Self
Momentary loudness over a sliding 400 ms window. Reported via
Snapshot::momentary_lufs and
Report::momentary_max_lufs.
Sourcepub const ShortTerm: Self
pub const ShortTerm: Self
Short-term loudness over a sliding 3 s window. Reported via
Snapshot::short_term_lufs and
Report::short_term_max_lufs.
Sourcepub const TruePeak: Self
pub const TruePeak: Self
True-peak via 4× oversampling FIR per BS.1770 Annex 2.
Reported via Report::true_peak_dbtp.
Sourcepub const Lra: Self
pub const Lra: Self
Loudness range per EBU Tech 3342. Reported via
Report::loudness_range_lu.
Sourceimpl Mode
impl Mode
Sourcepub const fn bits(&self) -> u8
pub const fn bits(&self) -> u8
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u8) -> Option<Self>
pub const fn from_bits(bits: u8) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u8) -> Self
pub const fn from_bits_truncate(bits: u8) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u8) -> Self
pub const fn from_bits_retain(bits: u8) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl Mode
impl Mode
Sourcepub const fn iter(&self) -> Iter<Mode>
pub const fn iter(&self) -> Iter<Mode>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<Mode>
pub const fn iter_names(&self) -> IterNames<Mode>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.